##  Importing IT Components Using Inventory Builder
The inventory builder function uses AI to analyze diagrams, images, and text-based file formats to automatically extract relevant architectural elements. This is useful if your organization already has pre-collated enterprise architecture diagrams and images.
The analysis discovers appropriate fact sheets and their relationships and lists them in the inventory builder inbox. In the inbox, you can do the following:
  * Review the extracted items and create corresponding fact sheets.
  * If a corresponding IT component fact sheet already exists in your inventory, then you can link the item to the existing fact sheet.
  * Create relations to other fact sheets that are discovered from the uploaded diagram.


At the same time, the fact sheets are also linked to the reference catalog item, ensuring they stay updated as the catalog data evolves. It also links the IT component fact sheet to the associated provider and tech category fact sheets if you have configured the reference catalog that way. To learn more, see [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.").
For a more detailed guide, see [Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory builder uses AI to analyze diagrams, images, and text-based files. It extracts fact sheets and relations to help you build your inventory faster. You can review, adjust, and create fact sheets from discovered data.").
**Note**
You need to activate the feature in the Optional Features & Early Access section of admin settings. For a detailed guide, see [Activating the Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder?locale=en-US&state=PRODUCTION&version=CLOUD#loio275aa8177a441014a545bcdc6c1c2579__Activating-the-Inventory-Builder).
